@@ -190,37 +190,22 @@ class DVPOAuth:
         }
         return res
 
-    def soap_U_format(self):
+    def soap_U_format(self, resp=None):
         return_dict = {
             'AccountSearchSequence': {
                 'AccountSearchSequence': []
             },
-            'Header': {
-                'DateTimeStamp': None,
-                'MessageText': 'Validation fails: Invalid Account Number 12345',
-                'Result': 'U',
-                'ReturnCode': None
-            },
-            'MoreData': None,
-            'RowsReturned': None
-        }
-        return return_dict
-
-    def soap_W_format(self):
-        return_dict = {
-            'AccountSearchSequence': None,
             'Header': {
                 'DateTimeStamp': datetime.now().strftime("%Y-%m-%d-%H.%M.%S.%f"),
-                'MessageText': 'No matches found for search criteria',
-                'Result': 'W',
-                'ReturnCode': 'A0016'
+                'MessageText': resp.get('ReturnMessageText',''),
+                'Result': resp.get('InternetReturnCode', ''),
+                'ReturnCode': resp.get('ErrorCode', '')
             },
-            'MoreData': 'N',
-            'RowsReturned': '0000'
+            'MoreData': resp.get('MoreData', ''),
+            'RowsReturned': resp.get('RowsReturned', '')
         }
         return return_dict
 
-
     def convert_account_search_json_from_oauth_to_soap(
         self, status_code=None, resp=None
     ):
@@ -229,10 +214,7 @@ class DVPOAuth:
             return None
 
         if resp['d']['results'][0]['InternetReturnCode'] == 'U':
-            return self.soap_U_format()
-
-        if resp['d']['results'][0]['InternetReturnCode'] == 'W':
-            return self.soap_W_format()
+            return self.soap_U_format(resp['d']['results'][0])
 
         resp_parent = resp["d"]["results"][0]
         data = resp_parent["ZAcctSearchNav"]["results"][0]
